/*
 * Sean Landman
 * Data Mining for Biomedical Informatics Group
 * University of Minnesota - Twin Cities
 */

package edu.umn.cs.kumarbio.shear.realignment;

/**
 * Represents a record in a SAM file. This class is just used by the
 * BreakpointsRealigner class.
 */
public class SamRecord {

  // Relevant fields for the SAM record
  public String  queryName;
  public int     samFlag;
  public String  referenceName;
  public long    pos;
  public int     mapq;
  public String  cigar;
  public String  mateReferenceName;
  public long    matePos;
  public int     templateLength;
  public String  sequence;
  public String  quality;
  public String  optionalFields;

  // Whether or not the read has been processed while compiling realigned data (see BreakpointsRealigner class)
  public boolean readProcessed;

  /**
   * Creates a new SamRecord object. Initializes readProcessed to false.
   *
   * @param queryName
   *          The query name for the SAM record
   * @param samFlag
   *          The flag for the SAM record
   * @param referenceName
   *          The reference name for the SAM record
   * @param pos
   *          The position for the SAM record
   * @param mapq
   *          The mapping quality for the SAM record
   * @param cigar
   *          The CIGAR string for the SAM record
   * @param mateReferenceName
   *          The reference name for the SAM record's mate
   * @param matePos
   *          The position for the SAM record's mate
   * @param templateLength
   *          The template length for the SAM record
   * @param sequence
   *          The sequence for the SAM record
   * @param quality
   *          The quality string for the SAM record
   * @param optionalFields
   *          Any optional fields associated with the SAM record
   */
  public SamRecord(
      String queryName, int samFlag, String referenceName, long pos, int mapq, String cigar, String mateReferenceName,
      long matePos, int templateLength, String sequence, String quality, String optionalFields) {
    this.queryName = queryName;
    this.samFlag = samFlag;
    this.referenceName = referenceName;
    this.pos = pos;
    this.mapq = mapq;
    this.cigar = cigar;
    this.mateReferenceName = mateReferenceName;
    this.matePos = matePos;
    this.templateLength = templateLength;
    this.sequence = sequence;
    this.quality = quality;
    this.optionalFields = optionalFields;
    readProcessed = false;
  }

}
